// (C) 2019-2023 GoodData Corporation
import React, { createContext, useContext, useDebugValue, useState } from "react";
import noop from "lodash/noop.js";
/**
 * @internal
 */
const PlaceholdersContext = createContext({
    state: {
        placeholders: {},
    },
    updateState: noop,
});
PlaceholdersContext.displayName = "PlaceholdersContext";
/**
 * @internal
 */
export const usePlaceholdersContext = () => useContext(PlaceholdersContext);
/**
 * Wraps component into a PlaceholdersContext consumer enabling the children of this to access the current
 * placeholders state.
 *
 * @public
 */
export function PlaceholdersProvider(props) {
    const { children, initialValues } = props;
    const accumulator = {};
    const initialPlaceholdersState = initialValues?.reduce((acc, [placeholder, value]) => {
        acc[placeholder.id] = {
            ...placeholder,
            value,
        };
        return acc;
    }, accumulator) ?? {};
    const [state, updateState] = useState({
        placeholders: initialPlaceholdersState,
    });
    useDebugValue(state);
    return (React.createElement(PlaceholdersContext.Provider, { value: {
            state,
            updateState,
        } }, children));
}
//# sourceMappingURL=context.js.map